* File to estimate effects of agreements with services provisions at GTAP sector level
********************************************************
use itpd_wb_services, clear //dta file generated by data_clean code

//(1) ITPD to GTAP concordances
merge m:1 industry_id using itpd_gtap_concordance, nogen
drop if gtap=="drop"

//Split 162 b/w obs and cmn
expand 2 if industry_id==162, gen(cmn)
replace gtap="cmn" if industry_id==162 & cmn==1
replace gtap="obs" if industry_id==162 & cmn==0
replace trade=0.26*trade if gtap=="cmn"
replace trade=0.74*trade if gtap=="obs"
drop cmn

//Collapse by gtap sector
collapse (sum) trade (mean) Services_Nomissing (first) agreement type gtap_description WB_merge, by(exporter_iso3 importer_iso3 year gtap)
sort exporter_iso3 importer_iso3 gtap year

*(2) Create RTA dummies by type
replace type="No RTA" if type==""
replace Services_Nomissing=0 if type=="No RTA"  //code missing services when no RTA
replace Services_Nomissing=0 if Services_Nomissing==.

tab type, gen(pta)
gen eia_cu=pta1+pta2 
gen fta=pta3+pta4 
gen rta=fta+eia_cu   

gen fta_services=0
replace fta_services=1 if Services_Nomissing!=0 & fta==1 //FTAs with atleast 1 services provision coded
gen rta_services=0
replace rta_services=1 if Services_Nomissing!=0 //RTAs with atleast 1 services provisions

//EU dummy
gen eu=0
replace eu=1 if agreement=="EC (15) Enlargement"
replace eu=1 if agreement=="EC (25) Enlargement"
replace eu=1 if agreement=="EC (27) Enlargement"
replace eu=1 if agreement=="EU (28) Enlargement"

//(3) Generate fixed effects
egen exp=group(exporter_iso3)
egen imp=group(importer_iso3)
egen sec=group(gtap)
gen ctry_pair = cond(exporter_iso3 <= importer_iso3, exporter_iso3, importer_iso3) + cond(exporter_iso3 >= importer_iso3, exporter_iso3, importer_iso3)

//(4a) Estimate effects using PPMLHDFE by core GTAP sector
keep if gtap=="cmn" | gtap=="cns" | gtap=="ofi" | gtap=="obs"| gtap=="ins" | gtap=="trd"  //Services sectors covered by FTAs

matrix drop _all
matrix res=J(6,2,.)
local i=1
levelsof gtap, local(sec) clean
eststo clear
foreach k of local sec{ 
	ppmlhdfe trade rta_services eu if gtap=="`k'",a(exp#year imp#year exp#imp) cluster(exp#imp) 
	eststo e_`k',title(`k')
	matrix res[`i',1]=_b[rta_services]
	local t = _b[rta_services]/_se[rta_services]
    	matrix res[`i',2]=round(2*ttail(e(df),abs(`t')),0.01)
	local i=`i'+1
	}
esttab using gtap_services_results.csv, mtitles se(2) star(* 0.1 ** 0.05 *** 0.01) replace //Replicates results in Table F6

//(4b) Calculate AVE changes by sector
matrix input esub=(3.0,.\3.8,.\5.9, .\5.6, .\5.9, .\5.2, .)
matrix ave_res=(res,esub)

local r=rowsof(ave_res)
forvalues i=1/`r' {
	if ave_res[`i',2]<=0.10{
		matrix ave_res[`i',4]=(exp(-ave_res[`i',1]/(ave_res[`i',3]-1))-1)*100
}
}

matrix colnames ave_res=rta_coefficient p-value Armington_elasticty ave_tariff
matrix rownames ave_res=cmn cns ins obs ofi trd
mat2txt, matrix(ave_res) saving(ave_services) //Reports ad valorem equivalent changes for GTAP services sectors in Table 3.5



