* File to estimate provision level effects of agreements with services provisions at ITPD-E sector level
********************************************************
use itpd_wb_services, clear //dta file generated by data_clean code
keep if industry_id==158 | industry_id==159 | industry_id==160 | industry_id==161 | industry_id==162 | industry_id==163 | industry_id==169 //Core ITPD-E services sectors

//(1) Create RTA dummies by type
replace type="No RTA" if type==""
replace Services_Nomissing=0 if type=="No RTA"  //code missing services when no RTA
replace Services_Nomissing=0 if Services_Nomissing==.

tab type, gen(pta)
gen eia_cu=pta1+pta2 
gen fta=pta3+pta4 
gen rta=fta+eia_cu   

gen fta_services=0
replace fta_services=1 if Services_Nomissing!=0 & fta==1 //FTAs with atleast 1 services provision coded
gen rta_services=0
replace rta_services=1 if Services_Nomissing!=0 //RTAs with atleast 1 services provisions

//(2) EU dummy
gen eu=0
replace eu=1 if agreement=="EC (15) Enlargement"
replace eu=1 if agreement=="EC (25) Enlargement"
replace eu=1 if agreement=="EC (27) Enlargement"
replace eu=1 if agreement=="EU (28) Enlargement"

//(3) Construct fixed effects
egen exp=group(exporter_iso3)
egen imp=group(importer_iso3)
egen sec=group(industry_id)
gen ctry_pair = cond(exporter_iso3 <= importer_iso3, exporter_iso3, importer_iso3) + cond(exporter_iso3 >= importer_iso3, exporter_iso3, importer_iso3)

//(4) Constructing provision buckets
*Liberalization Approach* 
//Full Liberalization
gen Serviceslib_full=rta_services //copy of rta_service dummy
replace Serviceslib_full = 0 if (Services_s_lib_app!="3") &  (rta_services==1)
replace Serviceslib_full = 0 if (Services_s_lib_stand!="1") & (rta_services==1)
replace Serviceslib_full = 0 if (Services_s_lib_rat!="1") & (rta_services==1) //only neg list and standstill and ratchet coded as 1

//Partial Liberalization Negative List and Positive List//
gen Serviceslib_partialposneg=rta_services //copy of rta_service dummy
replace Serviceslib_partialposneg = 0 if (Serviceslib_full!=0) & (rta_services==1) // negative list without full ratchet and standstill and postive list 

*Martket Access *  
//Change market acceess provisions to numeric values  
replace Services_dis_ma="3" if Services_dis_ma=="B" //US style market access
replace Services_dis_ma="2" if Services_dis_ma=="C" //other
replace Services_dis_ma="1" if Services_dis_ma=="A" //GATS sytle market access
destring Services_dis_ma, replace

gen Servicesdis_maUS=rta_services //copy of rta_service dummy
replace Servicesdis_maUS=0 if (Services_dis_ma!=3 & rta_services==1) // US style market access
gen Servicesdis_maother=rta_services //copy of rta_service dummy
replace Servicesdis_maother=0 if (Services_dis_ma>2 & rta_services==1) // GATS and other style market access 

* Other Substantive Disciplines*
destring Services_othdip_lpr, replace
replace Services_othdip_sen="." if Services_othdip_sen=="NA"
destring Services_othdip_sen, replace

replace Services_othdip_oth="." if Services_othdip_oth=="NA"
destring Services_othdip_oth, replace 

replace Services_othdip_ttr="." if Services_othdip_ttr=="NA"
destring Services_othdip_ttr, replace  

replace Services_othdip_lcr="." if Services_othdip_lcr=="NA"
destring Services_othdip_lcr, replace

replace Services_othdip_epr="." if Services_othdip_epr=="NA"
destring Services_othdip_epr, replace

egen Servicesotherdiptotal = rowtotal(Services_othdip_lpr Services_othdip_epr Services_othdip_lcr  Services_othdip_ttr Services_othdip_oth Services_othdip_sen)
gen Servicesotherdip_full=rta_services //copy of rta_service dummy
replace Servicesotherdip_full= 0 if (Servicesotherdiptotal<6 & rta_services==1) //all six disciplines are present

gen Servicesotherdip_partial=rta_services //copy of rta_service dummy
replace Servicesotherdip_partial= 0 if (Servicesotherdiptotal!=1 & rta_services==1) //only one of the discplines is present

// Five agreements have 3 or more provisions, but less than 6, and added to partial group
replace Servicesotherdip_partial= 1 if id==16
replace Servicesotherdip_partial= 1 if id==278
replace Servicesotherdip_partial= 1 if id==172
replace Servicesotherdip_partial= 1 if id==81
replace Servicesotherdip_partial= 1 if id==255 
 
gen Servicesotherdip_none=rta_services //copy of rta_service dummy
replace Servicesotherdip_none= 0 if (Servicesotherdiptotal>0 & rta_services==1) //none of the discplines is present 

//(5) Estimating provision effects with domestic production for subsample 
*Liberalization Approach*
eststo clear
levelsof industry_id, local(sec)
	foreach k of local sec{
		ppmlhdfe trade Serviceslib_full Serviceslib_partialposneg eu if industry_id==`k',a(exp#year imp#year exp#imp) cluster(ctry_pair) tol(1e-8)
		eststo e_`k',title(`k')
	}
esttab using Services_subsectors_provisions_lib.csv, mtitles se(2) star(* 0.1 ** 0.05 *** 0.01) replace
//Replicates results in Table F.16

*Market Access*
eststo clear
levelsof industry_id, local(sec)
	foreach k of local sec{
		ppmlhdfe trade Servicesdis_maUS Servicesdis_maother eu  if industry_id==`k',a(exp#year imp#year exp#imp) cluster(ctry_pair) tol(1e-8)
		eststo e_`k',title(`k')
	}
esttab using Services_subsectors_provisions_marketaccess.csv, mtitles se(2) star(* 0.1 ** 0.05 *** 0.01) replace
//Replicates results in Table F.17

*Other Substantive Disciplines*
eststo clear
levelsof industry_id, local(sec)
	foreach k of local sec{
		ppmlhdfe trade Servicesotherdip_full Servicesotherdip_partial Servicesotherdip_none eu  if industry_id==`k',a(exp#year imp#year exp#imp) cluster(ctry_pair) tol(1e-8)
		eststo e_`k',title(`k')
	}
esttab using Services_subsectors_provisions_otherareas.csv, mtitles se(2) star(* 0.1 ** 0.05 *** 0.01) replace
//Replicates results in Table F.18
